In-process codec registry โ supports multiple implementations per codec id, ranked by capability + priority + user preferences with init-time fallback.
Structs
- Codec
Implementation - One registered implementation: capability description + factories. Either / both factories may be present depending on whether the impl can decode, encode, or both.
- Codec
Registry